You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sis.apache.org by de...@apache.org on 2023/04/10 17:16:26 UTC

[sis] 02/02: Spelling fixes in documentation.

This is an automated email from the ASF dual-hosted git repository.

desruisseaux pushed a commit to branch geoapi-4.0
in repository https://gitbox.apache.org/repos/asf/sis.git

commit e172934869f89fb1d2fafa96bf0c0e75c921a98c
Author: Martin Desruisseaux <ma...@geomatys.com>
AuthorDate: Mon Apr 10 18:36:16 2023 +0200

    Spelling fixes in documentation.
---
 .../src/main/java/org/apache/sis/gui/coverage/CoverageCanvas.java   | 2 +-
 .../java/org/apache/sis/coverage/grid/DimensionalityReduction.java  | 4 ++--
 .../src/main/java/org/apache/sis/image/BandAggregateImage.java      | 4 ++--
 .../src/main/java/org/apache/sis/image/BandSelectImage.java         | 2 +-
 core/sis-feature/src/main/java/org/apache/sis/image/Colorizer.java  | 2 +-
 .../src/main/java/org/apache/sis/image/ComputedImage.java           | 2 +-
 .../src/main/java/org/apache/sis/image/ImageProcessor.java          | 4 ++--
 .../src/main/java/org/apache/sis/image/MultiSourceLayout.java       | 2 +-
 .../src/main/java/org/apache/sis/image/Visualization.java           | 4 ++--
 .../java/org/apache/sis/internal/coverage/MultiSourceArgument.java  | 4 ++--
 .../main/java/org/apache/sis/internal/coverage/RangeArgument.java   | 2 +-
 .../org/apache/sis/internal/coverage/j2d/ColorModelFactory.java     | 6 +++---
 .../java/org/apache/sis/internal/coverage/j2d/ColorsForRange.java   | 2 +-
 .../src/test/java/org/apache/sis/image/BandAggregateImageTest.java  | 6 +++---
 .../sis/referencing/operation/transform/PassThroughTransform.java   | 2 +-
 .../sis/referencing/operation/transform/TransformSeparator.java     | 2 +-
 .../org/apache/sis/storage/aggregate/BandAggregateGridResource.java | 6 +++---
 17 files changed, 28 insertions(+), 28 deletions(-)

diff --git a/application/sis-javafx/src/main/java/org/apache/sis/gui/coverage/CoverageCanvas.java b/application/sis-javafx/src/main/java/org/apache/sis/gui/coverage/CoverageCanvas.java
index 5cfe75de75..893b228927 100644
--- a/application/sis-javafx/src/main/java/org/apache/sis/gui/coverage/CoverageCanvas.java
+++ b/application/sis-javafx/src/main/java/org/apache/sis/gui/coverage/CoverageCanvas.java
@@ -413,7 +413,7 @@ public class CoverageCanvas extends MapCanvasAWT {
      * Sets the colorization algorithm to apply on rendered images.
      * Should be an algorithm based on coverage categories.
      *
-     * <p>{@code CoverageCanvas} can not detect when the given colorizer changes its internal state.
+     * <p>{@code CoverageCanvas} cannot detect when the given colorizer changes its internal state.
      * The {@link #stylingChanged()} method should be invoked explicitly when such change occurs.</p>
      *
      * @param colorizer colorization algorithm to apply on computed image, or {@code null} for default.
diff --git a/core/sis-feature/src/main/java/org/apache/sis/coverage/grid/DimensionalityReduction.java b/core/sis-feature/src/main/java/org/apache/sis/coverage/grid/DimensionalityReduction.java
index a6dc48d28c..517edb4390 100644
--- a/core/sis-feature/src/main/java/org/apache/sis/coverage/grid/DimensionalityReduction.java
+++ b/core/sis-feature/src/main/java/org/apache/sis/coverage/grid/DimensionalityReduction.java
@@ -225,7 +225,7 @@ public class DimensionalityReduction implements UnaryOperator<GridCoverage>, Ser
     /**
      * Returns all CRS components for the dimensions where the bit is set.
      * There is one CRS for each range of consecutive dimension indices.
-     * If at least one CRS can not be fetched, then this method returns {@code null}.
+     * If at least one CRS cannot be fetched, then this method returns {@code null}.
      *
      * @param  crs   the CRS for which to get components.
      * @param  axes  dimensions (or axis indices) of the components to get.
@@ -614,7 +614,7 @@ public class DimensionalityReduction implements UnaryOperator<GridCoverage>, Ser
     }
 
     /**
-     * Returns {@code true} if the {@code actual} CRS is equals, ignore metadata, to the one in {@code expected}.
+     * Returns {@code true} if the {@code actual} CRS is equal, ignore metadata, to the one in {@code expected}.
      * If any CRS is null, this method conservatively returns {@code true}.
      * This is used for assertions only.
      */
diff --git a/core/sis-feature/src/main/java/org/apache/sis/image/BandAggregateImage.java b/core/sis-feature/src/main/java/org/apache/sis/image/BandAggregateImage.java
index f1d06ca4b4..255176dcc8 100644
--- a/core/sis-feature/src/main/java/org/apache/sis/image/BandAggregateImage.java
+++ b/core/sis-feature/src/main/java/org/apache/sis/image/BandAggregateImage.java
@@ -58,7 +58,7 @@ class BandAggregateImage extends MultiSourceImage {
      */
 
     /**
-     * Returns potentially deeper sources than the user-supplied image.
+     * Returns potentially deeper sources than the user supplied image.
      * This method unwraps {@link BandSelectImage} for making possible to detect that two
      * consecutive images are actually the same image, with only different bands selected.
      *
@@ -194,7 +194,7 @@ class BandAggregateImage extends MultiSourceImage {
             }
         }
         /*
-         * Fallback when the data arrays can not be shared.
+         * Fallback when the data arrays cannot be shared.
          * This code copies all sample values in new arrays.
          */
         if (tile == null) {
diff --git a/core/sis-feature/src/main/java/org/apache/sis/image/BandSelectImage.java b/core/sis-feature/src/main/java/org/apache/sis/image/BandSelectImage.java
index 7dfd7c1279..2b126c5d28 100644
--- a/core/sis-feature/src/main/java/org/apache/sis/image/BandSelectImage.java
+++ b/core/sis-feature/src/main/java/org/apache/sis/image/BandSelectImage.java
@@ -106,7 +106,7 @@ class BandSelectImage extends SourceAlignedImage {
      *
      * @param  source  the image in which to select bands.
      * @param  bands   the bands to select. Not cloned in order to share common arrays when possible.
-     *                 If that array instance was user-supplied, then it should be cloned by caller.
+     *                 If that array instance was user supplied, then it should be cloned by caller.
      */
     static RenderedImage create(RenderedImage source, int... bands) {
         final int numBands = ImageUtilities.getNumBands(source);
diff --git a/core/sis-feature/src/main/java/org/apache/sis/image/Colorizer.java b/core/sis-feature/src/main/java/org/apache/sis/image/Colorizer.java
index e1f1d7a937..d7ee7fb9c7 100644
--- a/core/sis-feature/src/main/java/org/apache/sis/image/Colorizer.java
+++ b/core/sis-feature/src/main/java/org/apache/sis/image/Colorizer.java
@@ -329,7 +329,7 @@ public interface Colorizer extends Function<Colorizer.Target, Optional<ColorMode
 
     /**
      * Returns a new colorizer which will apply the specified alternative
-     * if this colorizer can not infer a color model.
+     * if this colorizer cannot infer a color model.
      *
      * @param  alternative  the alternative strategy for creating a color model.
      * @return a new colorizer which will attempt to apply {@code this} first,
diff --git a/core/sis-feature/src/main/java/org/apache/sis/image/ComputedImage.java b/core/sis-feature/src/main/java/org/apache/sis/image/ComputedImage.java
index 792bb06d08..fa024899ef 100644
--- a/core/sis-feature/src/main/java/org/apache/sis/image/ComputedImage.java
+++ b/core/sis-feature/src/main/java/org/apache/sis/image/ComputedImage.java
@@ -263,7 +263,7 @@ public abstract class ComputedImage extends PlanarImage implements Disposable {
     }
 
     /**
-     * Ensures that a user-supplied color model is compatible with the sample model.
+     * Ensures that a user supplied color model is compatible with the sample model.
      * This is a helper method for argument validation in sub-classes constructors.
      *
      * @param  colors  the color model to validate. Can be {@code null}.
diff --git a/core/sis-feature/src/main/java/org/apache/sis/image/ImageProcessor.java b/core/sis-feature/src/main/java/org/apache/sis/image/ImageProcessor.java
index ad9b1fee78..a6149ea3f0 100644
--- a/core/sis-feature/src/main/java/org/apache/sis/image/ImageProcessor.java
+++ b/core/sis-feature/src/main/java/org/apache/sis/image/ImageProcessor.java
@@ -395,7 +395,7 @@ public class ImageProcessor implements Cloneable {
      * Consequently the colorizer is not invoked for that operation.</p>
      *
      * <p>But by contrast, the color model of an {@link #aggregateBands(RenderedImage...) aggregateBands(…)}
-     * operation can not be determined in such straightforward way.
+     * operation cannot be determined in such straightforward way.
      * If three or four bands are aggregated, should they be interpreted as an (A)RGB image?
      * The {@link Colorizer} allows to specify the desired behavior.</p>
      *
@@ -1325,7 +1325,7 @@ public class ImageProcessor implements Cloneable {
      *
      * <h4>How to specify colors</h4>
      * The image colors can be controlled by the {@link Colorizer} set on this image processor.
-     * It is possible to {@linkplain Colorizer#forInstance(ColorModel) specify explicitely} the
+     * It is possible to {@linkplain Colorizer#forInstance(ColorModel) specify explicitly} the
      * {@link ColorModel} to use, but this approach is unsafe because it depends on the pixel values
      * <em>after</em> their conversion to the visualization image, which is implementation dependent.
      * A safer approach is to define colors relative to pixel values <em>before</em> their conversions.
diff --git a/core/sis-feature/src/main/java/org/apache/sis/image/MultiSourceLayout.java b/core/sis-feature/src/main/java/org/apache/sis/image/MultiSourceLayout.java
index 7ce6ba198b..415915c93e 100644
--- a/core/sis-feature/src/main/java/org/apache/sis/image/MultiSourceLayout.java
+++ b/core/sis-feature/src/main/java/org/apache/sis/image/MultiSourceLayout.java
@@ -359,7 +359,7 @@ final class MultiSourceLayout extends ImageLayout {
      * then the returned color model will reuse the colors of that visible band.
      * Otherwise a grayscale color model is built with a value range inferred from the data-type.
      *
-     * @param  colorizer  user-supplied provider of color model, or {@code null} if none.
+     * @param  colorizer  user supplied provider of color model, or {@code null} if none.
      */
     final ColorModel createColorModel(final Colorizer colorizer) {
         ColorModel colors = null;
diff --git a/core/sis-feature/src/main/java/org/apache/sis/image/Visualization.java b/core/sis-feature/src/main/java/org/apache/sis/image/Visualization.java
index c7c44fa529..1b86bdd292 100644
--- a/core/sis-feature/src/main/java/org/apache/sis/image/Visualization.java
+++ b/core/sis-feature/src/main/java/org/apache/sis/image/Visualization.java
@@ -279,7 +279,7 @@ final class Visualization extends ResampledImage {
             }
             /*
              * Sample values will be unconditionally converted to integers in the [0 … 255] range.
-             * The sample model is a mandatory argument before we invoke user-supplied colorizer,
+             * The sample model is a mandatory argument before we invoke user supplied colorizer,
              * which must be done before to build the color model.
              */
             sampleModel = layout.createBandedSampleModel(ColorModelBuilder.TYPE_COMPACT, NUM_BANDS, source, bounds, 0);
@@ -320,7 +320,7 @@ final class Visualization extends ResampledImage {
                     builder.rescaleMainRange(sourceCM);
                 } else {
                     /*
-                     * At this point there is no more user-supplied colors (through `Colorizer`) that we can use.
+                     * At this point there is no more user supplied colors (through `Colorizer`) that we can use.
                      * If we have not been able to use the SampleDimension, try to use the ColorModel or SampleModel.
                      * There is no call to `rescaleMainRange(…)` because the following code already uses the range
                      * specified by the ColorModel, if available.
diff --git a/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/MultiSourceArgument.java b/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/MultiSourceArgument.java
index 6685ed04a8..51318aafec 100644
--- a/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/MultiSourceArgument.java
+++ b/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/MultiSourceArgument.java
@@ -178,7 +178,7 @@ public final class MultiSourceArgument<S> {
     }
 
     /**
-     * Replace a user-supplied source by a deeper source with the bands to select.
+     * Replace a user supplied source by a deeper source with the bands to select.
      * This is used for getting a flattened view of nested aggregations.
      */
     public final class Unwrapper {
@@ -204,7 +204,7 @@ public final class MultiSourceArgument<S> {
         private boolean done;
 
         /**
-         * Creates a new instance to be submitted to user-supplied {@link #unwrapper}.
+         * Creates a new instance to be submitted to user supplied {@link #unwrapper}.
          */
         private Unwrapper(final int index, final S source, final int[] bands) {
             this.index  = index;
diff --git a/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/RangeArgument.java b/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/RangeArgument.java
index e2ddedbda0..78103751c2 100644
--- a/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/RangeArgument.java
+++ b/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/RangeArgument.java
@@ -366,7 +366,7 @@ public final class RangeArgument {
 
     /**
      * Returns a color model for the bands specified by the user.
-     * This method may return {@code null} if the color model can not be created.
+     * This method may return {@code null} if the color model cannot be created.
      *
      * @param  colors  the original color model with all bands. Can be {@code null}.
      * @return the color model for a subset of bands, or null if the given color model was null.
diff --git a/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/j2d/ColorModelFactory.java b/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/j2d/ColorModelFactory.java
index 631d6663d2..108bada84f 100644
--- a/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/j2d/ColorModelFactory.java
+++ b/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/j2d/ColorModelFactory.java
@@ -597,7 +597,7 @@ public final class ColorModelFactory {
     /**
      * Creates a RGB color model for the given sample model.
      * The sample model shall use integer type and have 3 or 4 bands.
-     * This method may return {@code null} if the color model can not be created.
+     * This method may return {@code null} if the color model cannot be created.
      *
      * @param  model  the sample model for which to create a color model.
      * @return the color model, or null if a precondition does not hold.
@@ -666,7 +666,7 @@ public final class ColorModelFactory {
      *   <li>Input color model is recognized, but we cannot infer a proper color interpretation for given number of bands.</li>
      * </ul>
      *
-     * This method may return {@code null} if the color model can not be created.
+     * This method may return {@code null} if the color model cannot be created.
      *
      * <p><em>Note about {@link PackedColorModel} and {@link DirectColorModel}</em>:
      * those color models not managed for now, because they are really designed for
@@ -700,7 +700,7 @@ public final class ColorModelFactory {
      * Returns a color model with with the same colors but a different number of bands.
      * Current implementation supports {@link ComponentColorModel} with only one band,
      * {@link MultiBandsIndexColorModel} and {@link ScaledColorModel}.
-     * This method may return {@code null} if the color model can not be created.
+     * This method may return {@code null} if the color model cannot be created.
      *
      * @param  cm           the color model, or {@code null}.
      * @param  numBands     new number of bands.
diff --git a/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/j2d/ColorsForRange.java b/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/j2d/ColorsForRange.java
index d40c20196b..39c8d91d47 100644
--- a/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/j2d/ColorsForRange.java
+++ b/core/sis-feature/src/main/java/org/apache/sis/internal/coverage/j2d/ColorsForRange.java
@@ -137,7 +137,7 @@ final class ColorsForRange implements Comparable<ColorsForRange> {
      * <p>If no colors were explicitly defined but a fallback exists, then this method considers
      * this range as defined for allowing {@link ColorModelBuilder} to inherit those colors with
      * the range of values specified by {@link #originalSampleRange}. We conceptually accept any
-     * {@link #inheritedColors} even if {@link #toARGB(int)} can not handle all of them.</p>
+     * {@link #inheritedColors} even if {@link #toARGB(int)} cannot handle all of them.</p>
      */
     final boolean isUndefined() {
         return colors == null && inheritedColors == null;
diff --git a/core/sis-referencing/src/main/java/org/apache/sis/referencing/operation/transform/PassThroughTransform.java b/core/sis-referencing/src/main/java/org/apache/sis/referencing/operation/transform/PassThroughTransform.java
index 1ff924203f..aea2fa1455 100644
--- a/core/sis-referencing/src/main/java/org/apache/sis/referencing/operation/transform/PassThroughTransform.java
+++ b/core/sis-referencing/src/main/java/org/apache/sis/referencing/operation/transform/PassThroughTransform.java
@@ -270,7 +270,7 @@ public class PassThroughTransform extends AbstractMathTransform implements Seria
             if (subLower == 0 && subUpper == subDim) {
                 step = subTransform;
             } else {
-                // Restriction below apply only if the `subTransform` can not be used as a whole.
+                // Restriction below apply only if the `subTransform` cannot be used as a whole.
                 ArgumentChecks.ensureDimensionsMatch("subTransform", subDim, subDim, subTransform);
                 sep.addSourceDimensionRange(subLower, subUpper);
                 sep.addTargetDimensionRange(subLower, subUpper);
diff --git a/core/sis-referencing/src/main/java/org/apache/sis/referencing/operation/transform/TransformSeparator.java b/core/sis-referencing/src/main/java/org/apache/sis/referencing/operation/transform/TransformSeparator.java
index 67616b04fc..fe0495f17f 100644
--- a/core/sis-referencing/src/main/java/org/apache/sis/referencing/operation/transform/TransformSeparator.java
+++ b/core/sis-referencing/src/main/java/org/apache/sis/referencing/operation/transform/TransformSeparator.java
@@ -599,7 +599,7 @@ public class TransformSeparator {
              * If all source dimensions not in the sub-transform are consecutive numbers, we can use our passthrough
              * transform implementation. The "consecutive numbers" requirement (expressed in the `if` statement below)
              * is a consequence of a limitation in our current implementation: our current passthrough transform does
-             * not accept arbitrary indices for modified coordinates. We can not delegate to the static factory method
+             * not accept arbitrary indices for modified coordinates. We cannot delegate to the static factory method
              * `MathTransforms.passThrough(int[] modifiedCoordinates, ...)` because that method itself relies on this
              * `TransformSeparator` for separating the transform components at non-consecutive indices.
              */
diff --git a/storage/sis-storage/src/main/java/org/apache/sis/storage/aggregate/BandAggregateGridResource.java b/storage/sis-storage/src/main/java/org/apache/sis/storage/aggregate/BandAggregateGridResource.java
index 52e0f8b141..f548c4289d 100644
--- a/storage/sis-storage/src/main/java/org/apache/sis/storage/aggregate/BandAggregateGridResource.java
+++ b/storage/sis-storage/src/main/java/org/apache/sis/storage/aggregate/BandAggregateGridResource.java
@@ -205,7 +205,7 @@ public class BandAggregateGridResource extends AbstractGridCoverageResource {
      * This is the name specified at construction time.
      *
      * @return an identifier for the band aggregation.
-     * @throws DataStoreException if the identifier can not be obtained.
+     * @throws DataStoreException if the identifier cannot be obtained.
      */
     @Override
     public Optional<GenericName> getIdentifier() throws DataStoreException {
@@ -217,7 +217,7 @@ public class BandAggregateGridResource extends AbstractGridCoverageResource {
      * This grid geometry is inferred from the grid geometries of resources specified at construction time.
      *
      * @return extent of grid coordinates together with their mapping to "real world" coordinates.
-     * @throws DataStoreException if the grid geometry can not be obtained.
+     * @throws DataStoreException if the grid geometry cannot be obtained.
      */
     @Override
     public GridGeometry getGridGeometry() throws DataStoreException {
@@ -229,7 +229,7 @@ public class BandAggregateGridResource extends AbstractGridCoverageResource {
      * This is the union or a subset of the union of the ranges of all resources specified at construction time.
      *
      * @return ranges of sample values together with their mapping to "real values".
-     * @throws DataStoreException if the sample dimensions can not be obtained.
+     * @throws DataStoreException if the sample dimensions cannot be obtained.
      */
     @Override
     @SuppressWarnings("ReturnOfCollectionOrArrayField")
diff --git a/core/sis-feature/src/test/java/org/apache/sis/image/BandAggregateImageTest.java b/core/sis-feature/src/test/java/org/apache/sis/image/BandAggregateImageTest.java
index 144510cee8..c0b7adf5cf 100644
--- a/core/sis-feature/src/test/java/org/apache/sis/image/BandAggregateImageTest.java
+++ b/core/sis-feature/src/test/java/org/apache/sis/image/BandAggregateImageTest.java
@@ -250,7 +250,7 @@ public final class BandAggregateImageTest extends TestCase {
             expected[119] = 250;
             assertSame(target, result.getTile(tileX, tileY));
             assertArrayEquals(expected, result.getData().getPixels(minX, minY, width, height, (int[]) null));
-            return;             // Can not continue the tests because the source images have been modified.
+            return;             // Cannot continue the tests because the source images have been modified.
         }
         /*
          * Repeat the test with a custom band selection.
@@ -302,7 +302,7 @@ public final class BandAggregateImageTest extends TestCase {
 
     /**
      * Tests the aggregation of three tiled images having different tile matrices.
      * A copy of sample values can not be avoided in this case.
      */
     @Test
     @DependsOnMethod("testSimilarlyTiledImages")
@@ -351,7 +351,7 @@ public final class BandAggregateImageTest extends TestCase {
 
     /**
      * Tests the aggregation of three tiled images having different extents and different tile matrices.
      * A copy of sample values can not be avoided in this case, except on the second image.
      */
     @Test
     @DependsOnMethod("testImagesUsingSameExtentButDifferentTileSizes")
@@ -302,7 +302,7 @@ public final class BandAggregateImageTest extends TestCase {
     /**
      * Tests the aggregation of three tiled images having different tile matrices.
-     * A copy of sample values can not be avoided in this case.
+     * A copy of sample values cannot be avoided in this case.
      */
     @Test
@@ -351,7 +351,7 @@ public final class BandAggregateImageTest extends TestCase {
     /**
      * Tests the aggregation of three tiled images having different extents and different tile matrices.
-     * A copy of sample values can not be avoided in this case, except on the second image.
+     * A copy of sample values cannot be avoided in this case, except on the second image.
      */
     @Test